# -*- coding: utf-8 -*-
"""
    pip_services_container.build.__init__
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    Container build module initialization
    
    :copyright: Conceptual Vision Consulting LLC 2015-2016, see AUTHORS for more details.
    :license: MIT, see LICENSE for more details.
"""

__all__ = ['DefaultContainerFactory']

from .DefaultContainerFactory import DefaultContainerFactory
