# -*- coding: utf-8 -*-
"""
    pip_services_container.__init__
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    Container module initialization
    
    :copyright: Conceptual Vision Consulting LLC 2015-2016, see AUTHORS for more details.
    :license: MIT, see LICENSE for more details.
"""

__all__ = [ 'Container', 'ProcessContainer' ]

from .Container import Container
from .ProcessContainer import ProcessContainer

