# -*- coding: utf-8 -*-
"""
    pip_services_container.info.__init__
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    Container info module initialization
    
    :copyright: Conceptual Vision Consulting LLC 2015-2016, see AUTHORS for more details.
    :license: MIT, see LICENSE for more details.
"""

__all__ = [ 'ContainerInfo', 'ContainerInfoFactory' ]

from .ContainerInfo import ContainerInfo
from .ContainerInfoFactory import ContainerInfoFactory


